piecash_utilities.report_example package
========================================

Submodules
----------

piecash_utilities.report_example.report_simplest module
-------------------------------------------------------

.. automodule:: piecash_utilities.report_example.report_simplest
    :members:
    :undoc-members:
    :show-inheritance:

piecash_utilities.report_example.report_simplest_book module
------------------------------------------------------------

.. automodule:: piecash_utilities.report_example.report_simplest_book
    :members:
    :undoc-members:
    :show-inheritance:

piecash_utilities.report_example.report_simplest_parameters module
------------------------------------------------------------------

.. automodule:: piecash_utilities.report_example.report_simplest_parameters
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: piecash_utilities.report_example
    :members:
    :undoc-members:
    :show-inheritance:
